@@ -30,7 +30,8 @@ NULL
 
 get_optdigits_task = function() {
   b = as_backend("optdigits")
-  task = mlr3::TaskClassif$new("optdigits", b, target = "binaryclass", positive = "P")
+  task = mlr3::TaskClassif$new("optdigits", b, target = "binaryclass", positive = "P",
+    label = "Optical Recognition of Handwritten Digits")
   b$hash = task$man = "mlr3data::mlr_tasks_optdigits"
   task
 }
